git-walk discovers git repositories by walking a file tree.
In git terminology a “walk” usually means a revwalk: traversing the commit
graph. git-walk does a different kind of walk: it traverses the
filesystem to discover repositories, reporting each checkout it finds
together with cheap, read-only git metadata, without ever invoking the
git binary.
This crate is a work in progress: the discovery API is not implemented yet.
Functions
- version
- Returns the version of the
git-walkcrate, as declared inCargo.toml.